Numerated Headers

# Numerated Headers Example

just click into the editable area:

Each specified header will be decorated with a prepended numeration.

# Headline 1

## Headline 2

### Headline 3

#### Headline 4

##### Headline 5

###### Headline 6

Here we test, a link and other formattings such as bold, italic or deleted text. You may also use formattings for maths 2 2 = 4 or chemical formulas like CO2. Or you may edit tables as you do in office products.